#
# spec file for package python3-pbr
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# A build cycle exists between python-extras and python-testtools. Thus, only
# enable testing with a build conditional (off by default):
%bcond_with test

Name:           python3-pbr
Version:        1.8.0
Release:        2.2
Summary:        Python Build Reasonableness
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://pypi.python.org/pypi/pbr
Source:         http://pypi.python.org/packages/source/p/pbr/pbr-%{version}.tar.gz
Source1:        python3-pbr-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Test requirements:
%if %{with test}
BuildRequires:  python3-fixtures >= 0.3.14
BuildRequires:  python3-hacking >= 0.9.2
BuildRequires:  python3-python-subunit >= 0.0.18
BuildRequires:  python3-testrepository >= 0.0.18
BuildRequires:  python3-testresources >= 0.2.4
BuildRequires:  python3-testscenarios >= 0.4
BuildRequires:  python3-testtools >= 0.9.34
%if 0%{?suse_version} <= 1310
# mock is built-in for python 3.4
BuildRequires:  python3-mock >= 1.0
%endif
%endif
%if 0%{?suse_version} <= 1310
# pip is built-in for python 3.4
BuildRequires:  python3-pip >= 1.4
Requires:       python3-pip >= 1.4
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
PBR is a library to automatically do a bunch of standard
things you want in your setup.py without you having to repeat
them every time. It will set versions, process requirements
files and generate AUTHORS and ChangeLog file all from git
information.

%prep
%setup -q -n pbr-%{version}
# Get rid of ugly build-time deps that require network:
sed -i "s/, 'sphinx\.ext\.intersphinx'//" doc/source/conf.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}/%{_bindir}/pbr %{buildroot}/%{_bindir}/pbr-%{py3_ver}
ln -s -f %{_sysconfdir}/alternatives/pbr %{buildroot}%{_bindir}/pbr
# create a dummy target for /etc/alternatives/pbr
touch %{buildroot}%{_sysconfdir}/alternatives/pbr
%fdupes -s %{buildroot}%{python_sitelib}

%if %{with test}
%check
python3 setup.py testr || true
%endif

%post
%_sbindir/update-alternatives \
    --install %{_bindir}/pbr pbr %{_bindir}/pbr-%{py3_ver} 20

%preun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove pbr %{_bindir}/pbr-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc README.rst AUTHORS LICENSE ChangeLog
%{_bindir}/pbr
%{_bindir}/pbr-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/pbr
%{python3_sitelib}/*

%changelog
* Sat Sep 19 2015 arun@gmx.de
- specfile:
  * removed patch (fixed upstream):
    0001-Remove-sphinx_config.init_values-manual-call.patch
- update to version 1.8.0:
  * Strip comments present in setup.cfg
  * Protect WSGI application with a critical section
- changes from version 1.7.0:
  * Have pbr egg_info.writer check PBR is enabled
- changes from version 1.6.0:
  * Strip comments in requirements files
  * Support Sphinx >=1.3 new protoype and warnings
* Sat Aug 15 2015 arun@gmx.de
-  update to version 1.5.0:
  * Handle git being entirely absent
  * We require the use of setuptools
* Sat Aug  8 2015 arun@gmx.de
- specfile:
  * add Changelog to %%doc
- update to version 1.4.0:
  * Fix docs for environment markers in extras
  * Export ChangeLog and AUTHORS in install
  * Updated from global requirements
  * Show how long the git querying takes
  * Add wsgi_scripts support to PBR
  * Updated from global requirements
* Tue Jul 28 2015 toddrme2178@gmail.com
- Don't depend on pip for python >= 3.4, since it is built-in.
* Tue Jul 28 2015 toddrme2178@gmail.com
- Split documentation into separate package to avoid dependency
  loop
* Mon Jul 27 2015 toddrme2178@gmail.com
- update to 1.3.0:
  * Wrap env markers in parens
  * Updated from global requirements
  * Add more documentation around building docs
  * Updated from global requirements
  * Use string for 'OS_TEST_TIMEOUT' default
  * Updated from global requirements
  * This documents the use of comments that work between 2.6, 2.7 and 3.4
- Add 0001-Remove-sphinx_config.init_values-manual-call.patch . Needed
  for newer Sphinx versions.
- update to 1.2.0:
  * Strip markers from test requirements
  * Revert "Remove sphinx_config.init_values(
- Implement update-alternatives
  - ------------------------------------------------------------------
* Mon Jul 27 2015 toddrme2178@gmail.com
- update to 1.3.0
  * Wrap env markers in parens
  * Updated from global requirements
  * Add more documentation around building docs
  * Updated from global requirements
  * Use string for 'OS_TEST_TIMEOUT' default
  * Updated from global requirements
  * This documents the use of comments that work between 2.6, 2.7 and 3.4
- update to 1.2.0
  * Strip markers from test requirements
* Tue Jun 30 2015 arun@gmx.de
- update to version 1.3.0:
  * Wrap env markers in parens
  * Updated from global requirements
  * Add more documentation around building docs
  * Use string for 'OS_TEST_TIMEOUT' default
  * This documents the use of comments that work between 2.6, 2.7 and
    3.4
- changes from version 1.2.0:
  * Strip markers from test requirements.
* Sun Jun 14 2015 arun@gmx.de
- update to version 1.1.1:
  * Revert "Remove sphinx_config.init_values() manual call"
- changes from version 1.1.0:
  * Fix test case to be runnable with gnupg 2.1
  * More explicit data_files install location docs
  * Move CapturedSubprocess fixture to base
  * Remove sphinx_config.init_values() manual call
  * Updated from global requirements
  * builddoc: allow to use fnmatch-style exclusion for autodoc
  * doc: add some basic doc about pbr doc options
  * Add home-page into sample setup.cfg
  * Make setup.py --help-commands work without testrepository
  * Add kerberos deps to build the kerberos wheel.
* Mon May 25 2015 arun@gmx.de
- update to version 1.0.1:
  * Remove self.pre_run calls in packaging.py
  * Update hacking to 0.10.x series
- changes from version 1.0.0:
  * Teach pbr to read extras and env markers
  * Bump integration test timeouts.
  * Finish removing invocations of pip.
  * Advertise support for Python3.4
  * Issue #1451976: handle commits with non-utf8 text
  * Parallelise integration tests.
  * Stop re-invoking pip
  * Allow overwriting sphinx builder from command line
* Sat May  2 2015 arun@gmx.de
- update to version 0.11.0:
  * Issue #1450210: Preversioning rc tag handling
  * Stop testing setup.py easy_install behaviour
  * Test pip install -e of projects.
  * Build all the wheels in one pass rather than many.
  * Improve integration.sh.
  * Honour new test variable PIPVERSION
  * Be safe, don't let friends use RawConfigParser
  * Revert "Support platform-specific requirements files"
  * Reinstate pure-git-hashes-are-illegal test.
  * Ignore non-release related tags
  * Test that MANIFEST.in excludes work
  * Fixup semver
  * Better diagnostics on test failure
  * Don't avoid egg-info quite so often
  * Add truncated lincense text
  * "packages" might list multiple directories
  * Support script text override for newer develop
  * Fixes Windows generated scripts headers
  * Update README format to match release notes tool
  * Be more aggressive about building wheels
  * Use a wheelhouse in the integration test
  * Build a wheel when integration testing PBR changes
  * Use unsafe OpenPGP keys for testing
  * Move write_pbr_json to avoid issues with nose
  * Properly check for git before getting git dir
  * Port in git sha changes from 0.10 line
  * Workflow documentation is now in infra-manual
  * Packagers vs package maintainers
  * Support platform-specific requirements files
  * Remove extraneous vim editor configuration comments
  * Clean up links and docs
  * Add user.name to git config in tests
  * Honour validly tagged versions.
  * autodoc: allow to exclude modules from auto-generation
  * tests: factorize has_opt handling
  * Support reading versions from wheels
  * Only consider tags that look like versions.
  * Refactor oneline changelog walking.
  * Stop using intersphinx
  * Retry the integration setup on connection error
  * Fixes a spelling error
  * Adds option for excluding files from autodoc trees
  * Allow for inclusion of authors and changelog when building docs
  * Work toward Python 3.4 support and testing
  * Accept capitalized Sem-Ver headers
  * use get_boolean_option for warnerrors
  * Handle more legacy version numbers
  * Look for and process sem-ver pseudo headers in git
  * Raise an error if preversion versions are too low
  * Teach pbr about post versioned dev versions.
  * Handle more local dev version cases
  * Introduce a SemanticVersion object
  * cleanup tox.ini
  * add docs env to tox
* Tue Mar  3 2015 arun@gmx.de
- update to version 0.10.8:
  * Support script text override for newer develop
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * always require pip for building
  * install pbr as pbr-%%{py3_ver}
- update to verson 0.10.7:
  * _get_revno only returns a commit count
- changes from version 0.10.6:
  * Integration test PBR commits
- changes from version 0.10.5:
  * Move write_pbr_json to avoid issues with nose
- changes from version 0.10.4:
  * Properly check for git before getting git dir
  * Use post version signifiers
  * Only import sphinx during hook processing
- changes from version 0.10.3:
  * Stop including git sha in version strings
  * Write and read more complex git sha info
- changes from version 0.10.1:
  * Prefix git suffixes with + instead of
- changes from version 0.10.2:
  * Remove all 2.7 filtering
  * Stop filtering out argparse
  * Remove mirror testing from the integration script
- changes from version 0.9.0:
  * Allow examining parsing exceptions
  * Update integration script for Apache 2.4
  * Restore Monkeypatched Distribution Instance
  * Register testr as a distutil entry point
  * Check for git before querying it for a version
  * Allow _run_cmd to run commands in any directory
  * Make setUp fail if sdist fails
  * Permit pre-release versions with git metadata
  * Un-nest some sections of code
- changes from version 0.8.2:
  * Remove --use-mailmap as it's not needed
  * Fix typos in docs
- changes from version 0.8.1:
  * pbr/testr_command.py: Add logging
  * Documentation updates
  * Fixed a typo in the documentation
  * Make source configurable when using --coverage
  * README.rst: tweaks
  * Format autoindex.rst file properly
  * make pbr use hacking directly
- changes from version 0.8.0:
  * Use unicode_literals import instead of u'unicode' notation
  * Add support for nested requirements files
  * Remove pip version specifier
  * Make tools/integration.sh take a branch
  * Fixes blocking issue on Windows
  * Remove duplicate git setup in tests
- changes from version 0.7.0:
  * Factor run_cmd out of the base class
  * Return the real class in VersionInfo __repr__
  * Fix up some docstrings
  * Init sphinx config values before accessing them
  * Remove copyright from empty files
  * Declare support for Python versions in setup.cfg
  * Updated from global requirements
  * Remove unused _parse_mailmap()
  * Add support for python 3-<3.3
  * Remove tox locale overrides
  * Do not force log verbosity level to info
- changes from version 0.6:
  * package: read a specific Python version requirement file
  * Fix typos in documents
  * Pin sphinx to <1.2
  * Build mirror using proper requirements
  * Use wheels for installation
  * show diff between pip installed packages and requirements
  * Enable wheel processing in the tests
  * Clean up integration script
  * Let git do mailmap mapping for us
  * Make ChangeLog more condensed
  * Make sphinx builders configurable in LocalBuildDoc
  * Serve local mirror using apache
  * Bump the development status classifier
  * Support building wheels (PEP-427)
  * Ignore jenkins@openstack.org in authors building
  * Communicate to user when we skip a requirement
  * Base python 2.7 skip list on parsed names
  * Link to the documentation in the readme
  * Avoid using 'which' executable for finding git
  * Add wheel mirror structure awareness
  * Remove pip as an argument from mkvenv
  * Use pypi-mirror instead of jeepyb
- changes from version 0.5.23:
  * Fixed pbr install to not error out and fail if git is not installed
- changes from version 0.5.22:
  * Move base test case logic out of __init__.py
  * Comply with pep440
  * Prevent ordereddict installation on 2.7
  * Do not pass unicode where byte strings are wanted
  * Add the semver documentation
  * Get rid of PyPI URL override in integration test
  * Add a test for command registration
  * Switch away from tearDown for BaseTests
  * Fix test_changelog when git isn't globally setup
  * Rework run_shell_command
  * Update tox config to use latest upgrades
  * Add a hint for users who don't have git installed
  * Add pypy to tox.ini
  * Fix python-ldap mirroring
  * Stop checking periods in commit messages
  * Fixes issue with command escaping on Windows
  * Added documentation for packagers
  * Update requirements in integration test
  * Sync requirements with global requirements
  * Fix pep8 error
  * Add option to run testr serially
* Sat Oct 12 2013 p.drouand@gmail.com
- Initial python3 support
* Thu Aug  8 2013 speilicke@suse.com
- Update to version 0.5.21:
  + Replace setuptools_git with a smarter approach
* Mon Aug  5 2013 speilicke@suse.com
- Add python-pip requirement
* Sun Aug  4 2013 dmueller@suse.com
- update to 0.5.20:
  * Add support for globbing in data files
  * Stop trying to install old pip and setuptools
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.5.18:
  * support python setup.py test
  * various python 3.x compat fixes
* Thu Jul  4 2013 speilicke@suse.com
- Introduce a build conditional for running tests to break build cycle
  with python-oslo.config
* Tue Jul  2 2013 dmueller@suse.com
- update description
* Wed Jun 26 2013 cdenicolo@suse.com
- license update: Apache-2.0
  license SUSE-Xano license not found in package. See LICENSE file.
* Wed Jun 26 2013 dmueller@suse.com
- remove python-discover dependency for newer distros
* Fri Jun 21 2013 dmueller@suse.com
- update to 0.5.17:
  * Remove dependency on distribute
  * Fix pip invocation for old versions of pip.
- remove 0001-Use-pip-instead-of-easy_install-for-installation.patch
- remove 0001-Skip-git-checkout-related-tests-when-.git-is-missing.patch
* Mon Jun 10 2013 dmueller@suse.com
- add 0001-Use-pip-instead-of-easy_install-for-installation.patch
* Mon Jun 10 2013 dmueller@suse.com
- update to 0.5.14:
  * Remove jinja pin.
  * Explicitly install install_requires.
  * More python3 compatibility.
  * Fix tox.ini to not reference deleted testenv
  * Fix doc autoindexing.
  * Add missing files to the tarball.
- add 0001-Skip-git-checkout-related-tests-when-.git-is-missing.patch
* Mon May 27 2013 dmueller@suse.com
- update to 0.5.10:
  + Default to single-version-externally-managed
  + Add config for skipping authors and changelog.
  + Update to d2to1 0.2.10.
* Tue May  7 2013 speilicke@suse.com
- Buildrequire python-python-mimeparse and use testr instead of nosetests.
  The pbr testsuite needs some proper setup to pass successfully.
* Thu May  2 2013 speilicke@suse.com
- Initial version
